@@ -1,12 +1,12 @@
 from manga_py.provider import Provider
+from manga_py.download_methods import WholeArchiveDownloader
 from .helpers.std import Std
-from .helpers._http2 import Http2
-
 
 class MangaFreakNet(Provider, Std):
+    _downloader = WholeArchiveDownloader
 
     def get_archive_name(self):
-        return self.chapter[0]
+        return self.chapter['archive_name']
 
     def get_chapter_index(self) -> str:
         return self.re.search(r'.+_(\d+)', self.chapter[1]).group(1)
@@ -19,11 +19,7 @@ class MangaFreakNet(Provider, Std):
 
     def get_chapters(self):
         items = self._elements('.manga_series_list td a[download]')
-        return [(i.get('download'), i.get('href')) for i in items]
-
-    def loop_chapters(self):
-        items = self.chapters[::-1]
-        Http2(self).download_archives([i[1] for i in items])
+        return [{'archive_name': i.get('download'), 'download_link': i.get('href')} for i in items][::-1]
 
     def get_files(self):
         pass
@@ -35,7 +31,7 @@ class MangaFreakNet(Provider, Std):
         return self._cover_from_content('.manga_series_image img')
 
     def chapter_for_json(self):
-        return self.chapter[1]
+        return self.chapter['download_link']
 
 
 main = MangaFreakNet
